@@ -46,17 +46,17 @@ KFeedbackDialog::KFeedbackDialog( const TQString & feedbackMailAddress,
     layout->addWidget( _form );
     checkSendButton();
 
-    connect( this,  TQT_SIGNAL( applyClicked() ),
-	     _form, TQT_SLOT  ( sendMail()  ) );
+    connect( this,  TQ_SIGNAL( applyClicked() ),
+	     _form, TQ_SLOT  ( sendMail()  ) );
 
-    connect( _form, TQT_SIGNAL( mailSent() 	),
-	     this,  TQT_SLOT  ( hide()	) );
+    connect( _form, TQ_SIGNAL( mailSent() 	),
+	     this,  TQ_SLOT  ( hide()	) );
 
-    connect( _form, TQT_SIGNAL( mailSent()	),
-	     this,  TQT_SIGNAL( mailSent()  ) );
+    connect( _form, TQ_SIGNAL( mailSent()	),
+	     this,  TQ_SIGNAL( mailSent()  ) );
 
-    connect( _form, TQT_SIGNAL( checkComplete()   ),
-	     this,  TQT_SLOT  ( checkSendButton() ) );
+    connect( _form, TQ_SIGNAL( checkComplete()   ),
+	     this,  TQ_SLOT  ( checkSendButton() ) );
 }
 
 
@@ -97,8 +97,8 @@ KFeedbackForm::KFeedbackForm( const TQString &	feedbackMailAddress,
     _questionList = new KFeedbackQuestionList( this );
     TQ_CHECK_PTR( _questionList );
     
-    connect( _questionList, TQT_SIGNAL( checkComplete()     ),
-	     this,	    TQT_SLOT  ( slotCheckComplete() ) );
+    connect( _questionList, TQ_SIGNAL( checkComplete()     ),
+	     this,	    TQ_SLOT  ( slotCheckComplete() ) );
 
 
     //
