@@ -68,17 +68,17 @@ KTreemapView::KTreemapView( KDirTree * tree, TQWidget * parent, const TQSize & i
 	}
     }
 
-    connect( this,	TQT_SIGNAL( selectionChanged( KFileInfo * ) ),
-	     tree,	TQT_SLOT  ( selectItem	( KFileInfo * ) ) );
+    connect( this,	TQ_SIGNAL( selectionChanged( KFileInfo * ) ),
+	     tree,	TQ_SLOT  ( selectItem	( KFileInfo * ) ) );
 
-    connect( tree,	TQT_SIGNAL( selectionChanged( KFileInfo * ) ),
-	     this,	TQT_SLOT  ( selectTile	( KFileInfo * ) ) );
+    connect( tree,	TQ_SIGNAL( selectionChanged( KFileInfo * ) ),
+	     this,	TQ_SLOT  ( selectTile	( KFileInfo * ) ) );
 
-    connect( tree,	TQT_SIGNAL( deletingChild	( KFileInfo * )	),
-	     this,	TQT_SLOT  ( deleteNotify	( KFileInfo * ) ) );
+    connect( tree,	TQ_SIGNAL( deletingChild	( KFileInfo * )	),
+	     this,	TQ_SLOT  ( deleteNotify	( KFileInfo * ) ) );
 
-    connect( tree,	TQT_SIGNAL( childDeleted()	 ),
-	     this,	TQT_SLOT  ( rebuildTreemap() ) );
+    connect( tree,	TQ_SIGNAL( childDeleted()	 ),
+	     this,	TQ_SLOT  ( rebuildTreemap() ) );
 }
 
 
@@ -181,12 +181,12 @@ KTreemapView::contentsMousePressEvent( TQMouseEvent * event )
 
     switch ( event->button() )
     {
-	case Qt::LeftButton:
+	case TQt::LeftButton:
 	    selectTile( tile );
 	    emit userActivity( 1 );
 	    break;
 
-	case Qt::MidButton:
+	case TQt::MidButton:
 	    // Select clicked tile's parent, if available
 
 	    if ( _selectedTile &&
@@ -208,7 +208,7 @@ KTreemapView::contentsMousePressEvent( TQMouseEvent * event )
 	    emit userActivity( 1 );
 	    break;
 
-	case Qt::RightButton:
+	case TQt::RightButton:
 
 	    if ( tile )
 	    {
@@ -247,7 +247,7 @@ KTreemapView::contentsMouseDoubleClickEvent( TQMouseEvent * event )
 
     switch ( event->button() )
     {
-	case Qt::LeftButton:
+	case TQt::LeftButton:
 	    if ( tile )
 	    {
 		selectTile( tile );
@@ -256,12 +256,12 @@ KTreemapView::contentsMouseDoubleClickEvent( TQMouseEvent * event )
 	    }
 	    break;
 
-	case Qt::MidButton:
+	case TQt::MidButton:
 	    zoomOut();
 	    emit userActivity( 5 );
 	    break;
 
-	case Qt::RightButton:
+	case TQt::RightButton:
 	    // Double-clicking the right mouse button is pretty useless - the
 	    // first click opens the context menu: Single clicks are always
 	    // delivered first. Even if that would be caught by using timers,
@@ -409,7 +409,7 @@ KTreemapView::rebuildTreemap( KFileInfo *	newRoot,
 
     if ( ! canvas() )
     {
-	TQCanvas * canv = new TQCanvas( TQT_TQOBJECT(this) );
+	TQCanvas * canv = new TQCanvas( this );
 	TQ_CHECK_PTR( canv );
 	setCanvas( canv );
     }
